@@ -2,4 +2,4 @@ import opics as op
 
 
 def test_c() -> None:
-    assert op.globals.c == 299792458
+    assert op.globals.C == 299792458
